@@ -43,8 +43,8 @@ sub run ($self) {
     }
 
     # check for distribution has configure PAR profiles in dist.perl
-    if ( !$self->dist->cfg->{par} && !ref $self->dist->cfg->{par} eq 'HASH' ) {
-        say q[par profile wasn't found.];
+    if ( !$self->dist->par_cfg ) {
+        say q[par script profile wasn't found.];
 
         exit 1;
     }
@@ -53,16 +53,16 @@ sub run ($self) {
     my $pcore_cfg = P->cfg->load( $ENV->share->get( '/data/pcore.perl', lib => 'Pcore' ) );
 
     # build scripts
-    for my $script ( sort keys $self->dist->cfg->{par}->%* ) {
+    for my $script ( sort keys $self->dist->par_cfg->%* ) {
         if ( !exists $pardeps->{$script}->{ $Config{archname} } ) {
             say BOLD . RED . qq[Deps for $script "$Config{archname}" wasn't scanned.] . RESET;
 
-            say qq[Run "$script ---scan-deps"];
+            say qq[Run "$script ---scan-deps".];
 
             next;
         }
 
-        my $profile = $self->dist->cfg->{par}->{$script};
+        my $profile = $self->dist->par_cfg->{$script};
 
         $profile->{dist}    = $self->dist;
         $profile->{script}  = P->path( $self->dist->root . 'bin/' . $script );
@@ -71,31 +71,30 @@ sub run ($self) {
         $profile->{upx}     = $self->upx if defined $self->upx;
         $profile->{clean}   = $self->clean if defined $self->clean;
 
+        if ( !-f $profile->{script} ) {
+            say BOLD . RED . qq[Script "$script" wasn't found.] . RESET;
+
+            next;
+        }
+
         # add pardeps.cbor modules, skip eval records
         $profile->{mod}->@{ grep { !/\A[(]eval\s/sm } keys $pardeps->{$script}->{ $Config{archname} }->%* } = ();
 
-        # add global modules
+        # add common modules
         $profile->{mod}->@{ $pcore_cfg->{par}->{mod}->@* } = ();
 
-        # add global ignored modules
-        $profile->{mod_ignore}->@{ $pcore_cfg->{par}->{mod_ignore}->@* } = ();
-
         # add global arch modules
         $profile->{mod}->@{ $pcore_cfg->{par}->{arch}->{ $Config{archname} }->{mod}->@* } = () if exists $pcore_cfg->{par}->{arch}->{ $Config{archname} }->{mod};
 
+        # remove common ignored modules
+        delete $profile->{mod}->@{ $pcore_cfg->{par}->{mod_ignore}->@* };
+
         # replace Inline.pm with Pcore/Core/Inline.pm
         $profile->{mod}->{'Pcore/Core/Inline.pm'} = undef if delete $profile->{mod}->{'Inline.pm'};
 
         # add Filter::Crypto::Decrypt deps if crypt mode is used
         $profile->{mod}->{'Filter/Crypto/Decrypt.pm'} = undef if $profile->{crypt};
 
-        # index and add script shares
-        my $share = {};
-
-        $share->@{ $profile->{share}->@* } = () if $profile->{share};
-
-        $profile->{share} = $share;
-
         # index and add shlib
         my $shlib = {};
 
@@ -120,7 +119,7 @@ sub run ($self) {
 ## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ## | Sev. | Lines                | Policy                                                                                                         |
 ## |======+======================+================================================================================================================|
-## |    3 | 56, 75, 103, 108     | References::ProhibitDoubleSigils - Double-sigil dereference                                                    |
+## |    3 | 56, 81, 102, 107     | References::ProhibitDoubleSigils - Double-sigil dereference                                                    |
 ## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ##
 ## -----SOURCE FILTER LOG END-----
